@@ -1,5 +1,4 @@
-"""
-Spike analysis software.
+"""Spike analysis software.
 
 """
 
@@ -7,7 +6,7 @@ from __future__ import division, print_function, absolute_import
 
 __author__ = "Marek Rudnicki"
 
-__version__ = "0.2"
+__version__ = "0.3"
 
 import os
 import sys
@@ -41,52 +40,24 @@ import thorns.waves
 
 from thorns.spikes import (
     make_trains,
-
     trains_to_array,
-
     accumulate,
-    accumulate_spikes,
-    accumulate_trains,
-    accumulate_spike_trains,
-
     select_trains,
-    select,
-    sel,
-
-    trim_spike_trains,
-    trim_trains,
     trim,
-
-    fold_spike_trains,
-    fold_trains,
     fold,
 )
 
 
 from thorns.stats import (
     get_duration,
-
     shuffled_autocorrelogram,
-    sac,
-
     correlation_index,
-    ci,
-
     firing_rate,
-    rate,
-
     psth,
-
     isih,
-
     entrainment,
-
-    synchronization_index,
-    si,
-
-    count_spikes,
-    count,
-
+    vector_strength,
+    spike_count,
     period_histogram
 )
 
